@@ -17,7 +17,7 @@
 #    along with wxBanker.  If not, see <http://www.gnu.org/licenses/>.
 
 import wx, datetime
-from wx.lib.pubsub import Publisher
+from wxbanker.lib.pubsub import Publisher
 from wxbanker.smoothsizer import SmoothStaticBoxSizer
 from wxbanker import localization
 
@@ -146,6 +146,7 @@ class UpdatableSearchCtrl(wx.SearchCtrl):
         self.SetFocus()
         self.SetValue(value)
         self.SetInsertionPoint(len(self.Value))
+        self.SetForegroundColour('BLACK')
             
         
 class HintedTextCtrl(UpdatableSearchCtrl):
@@ -166,6 +167,7 @@ class HintedTextCtrl(UpdatableSearchCtrl):
             self.ShowSearchButton(True)
 
         self.SetDescriptiveText(conf['hint'])
+        self.SetForegroundColour('DARK GRAY')
 
         try:
             self.Children[0].Bind(wx.EVT_CHAR, self.onChar)
@@ -176,6 +178,8 @@ class HintedTextCtrl(UpdatableSearchCtrl):
             pass
 
     def onChar(self, event):
+        self.SetForegroundColour('BLACK')
+
         if event.KeyCode == wx.WXK_TAB:
             if event.ShiftDown():
                 self.Navigate(wx.NavigationKeyEvent.IsBackward)
@@ -244,4 +248,4 @@ class FlashableButton(wx.BitmapButton):
             self.SetBitmapLabel(self.EmptyBitmap)
 
         # Now toggle the flash state.
-        self.FlashState = not self.FlashState
\ No newline at end of file
+        self.FlashState = not self.FlashState
