@@ -19,7 +19,7 @@
 #    along with wxBanker.  If not, see <http://www.gnu.org/licenses/>.
 
 from datetime import date, datetime
-from wx.lib.pubsub import Publisher
+from wxbanker.lib.pubsub import Publisher
 import codecs, csv, os, re
 from cStringIO import StringIO
 
