@@ -31,13 +31,7 @@ else:
     wxversion.ensureMinimal("2.8")
     import wx, wx.aui
 
-# Handle PubSub API change in 2.9.4.0
-try:
-    import wx.lib.pubsub.setupv1
-except ImportError:
-    pass
-
-from wx.lib.pubsub import Publisher
+from wxbanker.lib.pubsub import Publisher
 
 # wxBanker
 from wxbanker.menubar import BankMenuBar
@@ -100,6 +94,7 @@ class BankerPanel(wx.Panel):
             
         # Create the message panel.
         mpanel = messagepanel.MessagePanel(self, message)
+        print message, lines
         
         # If there are lines to display, add the button and callback
         if lines:
