@@ -20,7 +20,7 @@
 
 import wx, webbrowser, os
 from wx.lib.wordwrap import wordwrap
-from wx.lib.pubsub import Publisher
+from wxbanker.lib.pubsub import Publisher
 
 from wxbanker import version, localization, debug, fileservice, brandedframe
 from wxbanker.currencies import CurrencyStrings
@@ -142,9 +142,6 @@ class BankMenuBar(wx.MenuBar):
         self.Append(settingsMenu, _("&Settings"))
         self.Append(helpMenu, _("&Help"))
 
-        self.Bind(wx.EVT_MENU, self.onClickAbout)
-        helpMenu.Bind(wx.EVT_MENU, self.onClickAbout)
-
         self.toggleAutoSave(autosave)
         self.toggleShowCurrencyNick(showcurrnick)
         Publisher.subscribe(self.onAutoSaveToggled, "controller.autosave_toggled")
