@@ -18,7 +18,7 @@
 
 import wx
 from wxbanker import bankcontrols
-from wx.lib.pubsub import Publisher
+from wxbanker.lib.pubsub import Publisher
 
 
 class SearchCtrl(wx.Panel):
@@ -31,12 +31,14 @@ class SearchCtrl(wx.Panel):
 
         self.searchCtrl = bankcontrols.UpdatableSearchCtrl(self, value="", size=(200, -1), style=wx.TE_PROCESS_ENTER)
         # Try to grab the GTK system icon for clearing a search, otherwise we'll get the wxPython one.
-        clearBitmap = wx.ArtProvider.GetBitmap('edit-clear')
+        iconSize = self.searchCtrl.GetClientRect().GetHeight() - 2
+        clearBitmap = wx.ArtProvider.GetBitmap('edit-clear', wx.ART_OTHER, [iconSize, iconSize])
         if clearBitmap:
             self.searchCtrl.SetCancelBitmap(clearBitmap)
         self.searchCtrl.ShowCancelButton(True)
         self.searchCtrl.ShowSearchButton(False)
         self.searchCtrl.DescriptiveText = _("Search transactions")
+        self.searchCtrl.SetForegroundColour('DARK GRAY')
 
         # The More/Less button.
         self.moreButton = bankcontrols.MultiStateButton(self, labelDict={True: _("More options"), False: _("Less options")}, state=True)
@@ -96,6 +98,7 @@ class SearchCtrl(wx.Panel):
             self.onCancel()
         else:
             Publisher.sendMessage("SEARCH.INITIATED", searchInfo)
+            self.searchCtrl.SetForegroundColour('BLACK')
             
     def onExternalSearch(self, message):
         # If something else performs a search (such as Tag context menu), update the Value and search.
