@@ -30,7 +30,7 @@ TODO (for feature parity):
 
 import threading
 import wx, datetime
-from wx.lib.pubsub import Publisher
+from wxbanker.lib.pubsub import Publisher
 from wxbanker.ObjectListView import GroupListView, ColumnDefn, CellEditorRegistry
 from wxbanker import bankcontrols, tagtransactiondialog
 
@@ -338,7 +338,7 @@ class TransactionOLV(GroupListView):
                     tagItemMenu.Bind(wx.EVT_MENU, lambda e, tag=tag: self.onTagRemoval(tag, transactions), source=removeItem)
             else:
                 noTagsItem = tagsMenu.Append(-1, tagStr)
-                menu.Enable(noTagsItem.Id, False)
+                tagsMenu.Enable(noTagsItem.Id, False)
             tagsMenu.AppendSeparator()
             addItem = tagsMenu.Append(-1, addTagStr)
             tagsItem.SetSubMenu(tagsMenu)
